@@ -21,6 +21,7 @@ from braket.circuits.operator import Operator
 from braket.circuits.quantum_operator import QuantumOperator
 from braket.circuits.qubit import QubitInput
 from braket.circuits.qubit_set import QubitSet, QubitSetInput
+from braket.circuits.serialization import IRType, SerializationProperties
 
 # InstructionOperator is a type alias, and it can be expanded to include other operators
 InstructionOperator = Operator
@@ -101,12 +102,27 @@ class Instruction:
             return [Instruction(operator.counterpart(), self._target)]
         raise NotImplementedError(f"Adjoint not supported for {operator}")
 
-    def to_ir(self):
+    def to_ir(
+        self,
+        ir_type: IRType = IRType.JAQCD,
+        serialization_properties: SerializationProperties = None,
+    ):
         """
         Converts the operator into the canonical intermediate representation.
         If the operator is passed in a request, this method is called before it is passed.
+
+        Args:
+            ir_type(IRType) : The IRType to use for converting the instruction object to its
+                IR representation.
+            serialization_properties (SerializationProperties): The serialization properties to use
+                while serializing the object to the IR representation. The serialization properties
+                supplied must correspond to the supplied `ir_type`. Defaults to None.
         """
-        return self._operator.to_ir([int(qubit) for qubit in self._target])
+        return self._operator.to_ir(
+            [int(qubit) for qubit in self._target],
+            ir_type=ir_type,
+            serialization_properties=serialization_properties,
+        )
 
     @property
     def ascii_symbols(self) -> Tuple[str, ...]:
