@@ -20,6 +20,11 @@ from braket.circuits.free_parameter_expression import FreeParameterExpression
 from braket.circuits.parameterizable import Parameterizable
 from braket.circuits.quantum_operator import QuantumOperator
 from braket.circuits.qubit_set import QubitSet
+from braket.circuits.serialization import (
+    IRType,
+    OpenQASMSerializationProperties,
+    SerializationProperties,
+)
 
 
 class Noise(QuantumOperator):
@@ -56,15 +61,71 @@ class Noise(QuantumOperator):
         """
         return self.__class__.__name__
 
-    def to_ir(self, target: QubitSet) -> Any:
+    def to_ir(
+        self,
+        target: QubitSet,
+        ir_type: IRType = IRType.JAQCD,
+        serialization_properties: SerializationProperties = None,
+    ) -> Any:
         """Returns IR object of quantum operator and target
 
         Args:
             target (QubitSet): target qubit(s)
+            ir_type(IRType) : The IRType to use for converting the noise object to its
+                IR representation. Defaults to IRType.JAQCD.
+            serialization_properties (SerializationProperties): The serialization properties to use
+                while serializing the object to the IR representation. The serialization properties
+                supplied must correspond to the supplied `ir_type`. Defaults to None.
         Returns:
             IR object of the quantum operator and target
+
+        Raises:
+            ValueError: If the supplied `ir_type` is not supported, or if the supplied serialization
+            properties don't correspond to the `ir_type`.
         """
-        raise NotImplementedError("to_ir has not been implemented yet.")
+        if ir_type == IRType.JAQCD:
+            return self._to_jaqcd(target)
+        elif ir_type == IRType.OPENQASM:
+            if serialization_properties and not isinstance(
+                serialization_properties, OpenQASMSerializationProperties
+            ):
+                raise ValueError(
+                    "serialization_properties must be of type OpenQASMSerializationProperties "
+                    "for IRType.OPENQASM."
+                )
+            return self._to_openqasm(
+                target, serialization_properties or OpenQASMSerializationProperties()
+            )
+        else:
+            raise ValueError(f"Supplied ir_type {ir_type} is not supported.")
+
+    def _to_jaqcd(self, target: QubitSet) -> Any:
+        """
+        Returns the JAQCD representation of the noise.
+
+        Args:
+            target (QubitSet): target qubit(s).
+
+        Returns:
+            Any: JAQCD object representing the noise.
+        """
+        raise NotImplementedError("to_jaqcd has not been implemented yet.")
+
+    def _to_openqasm(
+        self, target: QubitSet, serialization_properties: OpenQASMSerializationProperties
+    ) -> str:
+        """
+        Returns the openqasm string representation of the noise.
+
+        Args:
+            target (QubitSet): target qubit(s).
+            serialization_properties (OpenQASMSerializationProperties): The serialization properties
+                to use while serializing the object to the IR representation.
+
+        Returns:
+            str: Representing the openqasm representation of the noise.
+        """
+        raise NotImplementedError("to_openqasm has not been implemented yet.")
 
     def to_matrix(self, *args, **kwargs) -> Any:
         """Returns a list of matrices defining the Kraus matrices of the noise channel.
