@@ -18,6 +18,11 @@ from typing import Any, Dict, List
 from braket.circuits.observable import Observable
 from braket.circuits.qubit import QubitInput
 from braket.circuits.qubit_set import QubitSet, QubitSetInput
+from braket.circuits.serialization import (
+    IRType,
+    OpenQASMSerializationProperties,
+    SerializationProperties,
+)
 
 
 class ResultType:
@@ -57,17 +62,59 @@ class ResultType:
         """
         return self.__class__.__name__
 
-    def to_ir(self, *args, **kwargs) -> Any:
+    def to_ir(
+        self,
+        ir_type: IRType = IRType.JAQCD,
+        serialization_properties: SerializationProperties = None,
+        **kwargs,
+    ) -> Any:
         """Returns IR object of the result type
 
         Args:
-            *args: Positional arguments
+            ir_type(IRType) : The IRType to use for converting the result type object to its
+                IR representation. Defaults to IRType.JAQCD.
+            serialization_properties (SerializationProperties): The serialization properties to use
+                while serializing the object to the IR representation. The serialization properties
+                supplied must correspond to the supplied `ir_type`. Defaults to None.
             **kwargs: Keyword arguments
 
         Returns:
             IR object of the result type
+
+        Raises:
+            ValueError: If the supplied `ir_type` is not supported, or if the supplied serialization
+            properties don't correspond to the `ir_type`.
         """
-        raise NotImplementedError("to_ir has not been implemented yet.")
+        if ir_type == IRType.JAQCD:
+            return self._to_jaqcd()
+        elif ir_type == IRType.OPENQASM:
+            if serialization_properties and not isinstance(
+                serialization_properties, OpenQASMSerializationProperties
+            ):
+                raise ValueError(
+                    "serialization_properties must be of type OpenQASMSerializationProperties "
+                    "for IRType.OPENQASM."
+                )
+            return self._to_openqasm(serialization_properties or OpenQASMSerializationProperties())
+        else:
+            raise ValueError(f"Supplied ir_type {ir_type} is not supported.")
+
+    def _to_jaqcd(self) -> Any:
+        """Returns the JAQCD representation of the result type."""
+        raise NotImplementedError("to_jaqcd has not been implemented yet.")
+
+    def _to_openqasm(self, serialization_properties: OpenQASMSerializationProperties) -> str:
+        """
+        Returns the openqasm string representation of the result type.
+
+        Args:
+            serialization_properties (OpenQASMSerializationProperties): The serialization properties
+                to use while serializing the object to the IR representation.
+
+        Returns:
+            str: Representing the openqasm representation of the result type.
+        """
+        raise NotImplementedError("to_openqasm has not been implemented yet.")
 
     def copy(
         self, target_mapping: Dict[QubitInput, QubitInput] = None, target: QubitSetInput = None
