@@ -19,7 +19,7 @@ import numpy as np
 import pytest
 
 from braket.circuits import Observable, ResultType
-from braket.ir import jaqcd
+from braket.ir import jaqcd, openqasm
 from braket.task_result import (
     AdditionalMetadata,
     GateModelTaskResult,
@@ -45,6 +45,22 @@ def additional_metadata():
     return AdditionalMetadata(action=program)
 
 
+@pytest.fixture
+def additional_metadata_openqasm():
+    program = openqasm.Program(
+        source="""
+        qubit[2] q;
+        bit[2] c;
+
+        h q[0];
+        cnot q[0], q[1];
+
+        c = measure q;
+        """
+    )
+    return AdditionalMetadata(action=program)
+
+
 @pytest.fixture
 def result_obj_1(task_metadata_shots, additional_metadata):
     return GateModelTaskResult(
@@ -167,6 +183,25 @@ def malformatted_results_2(task_metadata_shots, additional_metadata):
     ).json()
 
 
+@pytest.fixture
+def openqasm_result_obj_shots(task_metadata_shots, additional_metadata_openqasm):
+    return GateModelTaskResult.construct(
+        measurements=[[0, 0], [0, 1], [0, 1], [0, 1]],
+        measuredQubits=[0, 1],
+        taskMetadata=task_metadata_shots,
+        additionalMetadata=additional_metadata_openqasm,
+        resultTypes=[jaqcd.Probability()],
+    )
+
+
+def test_openqasm_shots_calculate_result_types(openqasm_result_obj_shots):
+    result = GateModelQuantumTaskResult._from_object_internal_computational_basis_sampling(
+        openqasm_result_obj_shots
+    )
+    assert result.result_types[0].type == jaqcd.Probability()
+    assert np.array_equal(result.result_types[0].value, [0.25, 0.75, 0, 0])
+
+
 test_ir_results = [
     (jaqcd.Probability(targets=[1]), np.array([0.6, 0.4])),
     (jaqcd.Probability(targets=[1, 2]), np.array([0.4, 0.2, 0.0, 0.4])),
